/**
* Tratamento do Cadastro Nacional de Pessoa Juridica
* @author Ivan Nagy
* @since 2002-10-17
**/
public final class CNPJ
{

	public CNPJ(){}

	/**
	* Retorna true para CNPJ valido ou false para CNPJ invalido.
	* Devera receber o numero do CNPJ sem formatacao-- o metodo
	* ira ignorar os numeros multiplos de 0
	* @param CNPJ
	* @return true para numero valido--false para numero invalido
	**/
	public static boolean isCNPJ( String pCNPJ ) throws Exception
	{
		int soma = 0;
		int resto = 0;

		try
		{
			/***** Verifica se digitado e' sequencia de numeros repetidos *****/
			if( pCNPJ.length() != 14 || pCNPJ.equals( "00000000000000" ) )
				return false;

			for( int i = 0; i < 4; i++ )
			{
				soma += Integer.parseInt( pCNPJ.substring( i,i + 1 ) ) * ( 5 - i );
			}

			for( int i = 4; i < 12; i++ )
			{
				soma += Integer.parseInt( pCNPJ.substring( i,i + 1 ) ) * ( 13 - i );
			}

			resto = ( soma % 11 );
			if( resto == 0 )
				resto = 1;

			resto = 11 - resto;

			resto = ( resto % 10 );

			if( resto != Integer.parseInt( pCNPJ.substring( 12,13 ) ) )
				return false;

			soma = 0;

			for( int i = 0; i < 5; i++ )
			{
				soma += Integer.parseInt( pCNPJ.substring( i,i + 1 ) ) * ( 6 - i );
			}

			for( int i = 5; i < 13; i++ )
			{
				soma += Integer.parseInt( pCNPJ.substring( i,i + 1 ) ) * ( 14 - i );
			}

			resto = ( soma % 11 );
			if( resto == 0 )
				resto = 1;

			resto = 11 - resto;

			resto = ( resto % 10 );

			if( resto != Integer.parseInt( pCNPJ.substring( 13,14 ) ) )
				return false;

			return true;
		}
		catch( Exception exp )
		{
			throw new Exception( "CNPJ invalido" );
		}

	}
}