import java.awt.*;
import java.util.Date;
import java.util.*;

/**
* Tratamento de Datas
* @author Ivan Nagy
* @since 2002-10-17
**/
public class Calendario
{
	private static final String DiaSemana[] = {"Domingo", "Segunda", "Tera", "Quarta",
				   			"Quinta", "Sexta", "Sabado"};

	private static final String Mes[] = {"Janeiro", "Fevereiro", "Maro", "Abril",
							 "Maio", "Junho", "Julho", "Agosto", "Setembro",
							 "Outubro", "Novembro", "Dezembro"};

	private static final Vector DiasMes = new Vector( 12 );

	public Calendario(){}

	/**
	* Retorna true para Data valida ou false para Data invalida.
	* Devera receber a string contendo a DATA -- Devera receber
	* a formatacao da data
	* @param Data Formato
	* @return true para data valido--false para data invalido
	**/
	public static boolean isDate( String pData, String pFormat ) throws Exception
	{
		int wYear,wMonth,wDay;

		wYear = 0;
		wMonth = 0;
		wDay = 0;

		try
		{
			if( pFormat.equals( "yyyy-mm-dd" ) )
			{
				// **********Format yyyy-mm-dd ********* //
				wYear = Integer.parseInt( pData.substring( 0,4 ) );
				wMonth = Integer.parseInt( pData.substring( 5,7 ) );
				wDay = Integer.parseInt( pData.substring( 8,10 ) );
			}
			else if( pFormat.equals( "dd-mm-yyyy" ) )
			{
				// **********Format dd-mm-yyyy ********* //
				wDay = Integer.parseInt( pData.substring( 0,2 ) );
				wMonth = Integer.parseInt( pData.substring( 3,5 ) );
				wYear = Integer.parseInt( pData.substring( 6,10 ) );
			}
			else
				return false;
		}
		catch( Exception exp )
		{
			throw new Exception( "Data invalida" );
		}

		setDias( wYear );

		// **********Verifica Ano********** //
		if( isYear( wYear ) == false )
			return false;

		// **********Verifica Mes********** //
		if( isMonth ( wMonth ) == false )
			return false;

		// **********Verifica Dia********** //
		if( isDiaMes( wMonth,wDay ) == false )
			return false;

		return true;
	}

	/**
	* Retorna true para Data valida ou false para Data invalida.
	* Devera receber a string contendo a DATA
	* #Default Assume o formato yyyy-mm-dd
	* @param Data
	* @return true para data valido--false para data invalido
	**/
	public boolean isDate( String pData ) throws Exception
	{
		int wYear,wMonth,wDay;

		wYear = 0;
		wMonth = 0;
		wDay = 0;

		try
		{
			// **********Format yyyy-mm-dd ********* //
			wYear = Integer.parseInt( pData.substring( 0,4 ) );
			wMonth = Integer.parseInt( pData.substring( 5,7 ) );
			wDay = Integer.parseInt( pData.substring( 8,10 ) );
		}
		catch( Exception exp )
		{
			throw new Exception( "Data invalida" );
		}

		setDias( wYear );

		// **********Verifica Ano********** //
		if( isYear( wYear ) == false )
			return false;

		// **********Verifica Mes********** //
		if( isMonth ( wMonth ) == false )
			return false;

		// **********Verifica Dia********** //
		if( isDiaMes( wMonth,wDay ) == false )
			return false;

		return true;
	}

	/**
	* Retorna true para Data valida ou false para Data invalida.
	* Devera receber os inteiros Ano,mes e dia
	* @param Ano,Mes,Dia
	* @return true para data valido--false para data invalido
	**/
	public boolean isDate( int pYear, int pMonth, int pDay ) throws Exception
	{
		try
		{
			setDias( pYear );

			// **********Verifica Ano********** //
			if( isYear( pYear ) == false )
				return false;

			// **********Verifica Mes********** //
			if( isMonth ( pMonth ) == false )
				return false;

			// **********Verifica Dia********** //
			if( isDiaMes( pMonth,pDay ) == false )
				return false;

			return true;
		}
		catch( Exception exp )
		{
			throw new Exception( "Data invalida" );
		}
	}

	private static void setDias( int pYear )
	{
		String wdias = "";

		DiasMes.add( 0, "0" );

		for( int widx = 1; widx <= 12; widx++ )
		{
			//{31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31}
			if( widx == 1 || widx == 3 || widx == 5 || widx == 7 || widx == 8 || widx == 10 || widx == 12 )
				wdias = "31";

			if( widx == 4 || widx == 6 || widx == 9 || widx == 11 )
				wdias = "30";

			if( widx == 2 )
			{
				wdias = "28";

				// ********Ano Bi-Sexto******** //
				if( isLeapYear( pYear ) == true )
					wdias = "29";
			}

			DiasMes.add( widx, wdias );
		}
	}

	private static boolean isYear( int pYear )
	{
		if( pYear < 1582 )
			return false;

		return true;
	}

	private static boolean isMonth( int pMonth )
	{
		if( pMonth < 1 || pMonth > 12 )
			return false;

		return true;
	}

	private static boolean isDiaMes( int pMonth, int pDay )
	{
		for( int widx = 1; widx <= Integer.parseInt( (String)DiasMes.get( pMonth ) ) ; widx++ )
		{
			if( pDay == widx )
				return true;
		}

		return false;
	}

	private static boolean isLeapYear(int year)
	{
		if ((year % 100) == 0) return((year % 400) == 0);

		return ((year % 4) == 0);
	}
}