// MyTableModel.java
/*********************************************
 Modelo de tabela abstrata

 Autor:	Edivaldo (S-Tecno)
 Criacao:	01 ago 2001
 Correcao:
*********************************************/

import javax.swing.table.AbstractTableModel;
import java.util.Vector;

public class MyTableModel extends AbstractTableModel
{
	private Vector colunas, linhas;
	private boolean  DEBUG = false;
	private int colsNotEditable;

	// Construtor
	public MyTableModel()
	{
		colunas = new Vector();
		linhas = new Vector();
		colsNotEditable=1;
	}

	public int getColumnCount()
	{
		return (colunas.size());
	}

	public int getRowCount()
	{
		int cols = getColumnCount();
		int itens = linhas.size();
		int mod, qtd = 0;
		if ((cols > 0) && (itens > 0))
		{
			mod = itens%cols;
			qtd = itens/cols;
			if (mod != 0) qtd++;
		}
		return ( qtd );
	}

	public String getColumnName(int col)
	{
		return colunas.get(col).toString();
	}

	public Object getValueAt(int row, int col)
	{
		int idx = getIdx(row, col);
		try
		{
			return linhas.get(idx);
		}
		catch (ArrayIndexOutOfBoundsException e)
		{
			return ( linhas.get(col) );
		}
	}

	protected int getIdx(int row, int col)
	{
		return (row * getColumnCount() + col);
	}

	public int getIndexOfString(String tab)
	{
		return linhas.lastIndexOf(tab);
	}

	public int getIndexOfString(String tab, int index)
	{
		return linhas.lastIndexOf(tab, index);
	}

	// Deleta elemento do vetor
	public void rowsDeleteElement(int index)
	{
		if (index >= 0 && index < linhas.size())
			linhas.removeElementAt(index);
	}

	public void columnAddElement(Object x)
	{
		colunas.addElement(x);
	}

	public void clear()
	{
		linhas.clear();
	}

	public void rowsAddElement(Object x)
	{
		linhas.addElement(x);
	}

	public Vector getVector()
	{
		return linhas;
	}

	// Cria o vetor para table
	public void makeVectorLinhas(Vector x) throws Exception
	{
		linhas = new Vector();

		try
		{
			for(int index=0; index < x.size(); index++) rowsAddElement(x.elementAt(index));
		}
		catch(Exception e)
		{
			throw e;
		}
	}

	public void setVector(Vector xv)
	{
		linhas = xv;
	}

	public void setVectorRowAt(int idx, Object value)
	{
		linhas.set(idx, value);
	}

	/*
	* JTable uses this method to determine the default renderer/
	* editor for each cell.  If we didn't implement this method,
	* then the last column would contain text ("true"/"false"),
	* rather than a check box.
	*/
	public Class getColumnClass(int c)
	{
		return getValueAt(0, c).getClass();
	}

	public void setNotEditable()
	{
		colsNotEditable = getColumnCount();
	}

	public void setEditable(int i)
	{
		if (i > getColumnCount())
			colsNotEditable = getColumnCount();
	}

	/*
	* Don't need to implement this method unless your table's
	* editable.
	*/
	public boolean isCellEditable(int row, int col)
	{
		//Note that the data/cell address is constant,
		//no matter where the cell appears onscreen.
		if (col < colsNotEditable)
		{
			return false;
		}
		else
		{
			return true;
		}
	}

	public void setValueAt(Object value, int row, int col)
	{
		if (DEBUG)
		{
			System.out.println("Setting value at " + row + "," + col + " to " + value + " (an instance of " + value.getClass() + ")");
		}

		linhas.set(getIdx(row, col), value);
		fireTableCellUpdated(row, col);

		if (DEBUG)
		{
			System.out.println("New value of data:");
			printDebugData();
		}
	}

	private void printDebugData()
	{
		int numRows = getRowCount();
		int numCols = getColumnCount();
		for (int i=0; i < numRows; i++)
		{
			System.out.print("    row " + i + ":");
			for (int j=0; j < numCols; j++)
			{
				String aux = getValueAt(i,j).toString();
				System.out.print("  " + aux );
			}

			System.out.println();
		}

		System.out.println("--------------------------");
	}
}
