import java.awt.*;
import java.awt.event.*;

public class FrameMsg extends Dialog
{
	public static final Parametro param = new Parametro();
    final int maxCharHeight = 17;
    final int minFontSize = 6;
    final int maxFontSize = 14;
    final Color bg = Color.lightGray;
    final Color fg = Color.black;
    Font biggestFont = new Font("SansSerif", Font.PLAIN, maxFontSize);

    Dimension totalSize;
    FontMetrics fontMetrics;

	FrameMsg( String titulo, String msg )
	{
		super(new Frame(""),titulo,true);
		setLayout(new BorderLayout(10,10));
		setSize(getLargura(msg)+23, 140);

		Button btOk = new Button("    OK    ");
		btOk.setEnabled(true);
		btOk.addActionListener(
			new ActionListener()
			{
				public void actionPerformed (ActionEvent e )
				{
					encerrar();
				}
			});

		Panel pnlBotao = new Panel(new FlowLayout());
		pnlBotao.add(btOk);

		Mensagem mensagem = new Mensagem(msg);
		add(mensagem, BorderLayout.CENTER);
		add(pnlBotao, BorderLayout.SOUTH);

		this.addWindowListener(
			new WindowAdapter()
			{
				public void windowClosing(WindowEvent e)
  	    		{
					encerrar();
				}

				public void windowDeactivated(WindowEvent e)
				{
					encerrar();
				}
	    	});

		Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
		Dimension frameSize = this.getSize();

		int posX, posY;
		posX = (screenSize.width - frameSize.width) / 2;
		posY = (screenSize.height - frameSize.height) / 2;
		setLocation (posX,posY);
		setResizable(false);

		setBackground(param.get_BackColor());
		setForeground(param.get_ForeColor());
		setFont(param.get_Fonte());

		show();
	}

	// Devolve a largura da mensagem
	int getLargura(String msg)
	{
		try
		{
			Font font = new Font("SansSerif", Font.PLAIN, maxFontSize);
			FontMetrics myMetrics = getFontMetrics(font);
			int largura = myMetrics.stringWidth(msg);
			if (largura > 700) return 700;
			if (largura < 200) return 200;
			return largura;
		}
		catch (Exception e)
		{
			return 400;
		}
	}

	private void encerrar()
	{
		this.dispose();
	}

	/***************************
	 Panel para entrada de dados
	****************************/
	private class Mensagem extends Panel
	{
		String mensag;

		public Mensagem(String msg)
		{
			mensag = msg;
		}

		public void update(Graphics g)
		{
			paint(g);
		}

		public synchronized void paint(Graphics g)
		{
			Dimension d = getSize();
	        Insets insets = getInsets();
	        int currentWidth = d.width - insets.left - insets.right;
	        int currentHeight = d.height - insets.top - insets.bottom;
	        int x = insets.left + 3;

			FontMetrics fontMetrics = pickFont(g, mensag, currentWidth);

        	int stringY = currentHeight - 5 - fontMetrics.getDescent();

	        g.drawString(mensag, x, stringY);

			g.setColor(param.get_BackColor());
			g.fill3DRect(0, 0, d.width - 1, d.height - 1, true);

			g.setColor(Color.yellow);
			g.drawRoundRect(5, 5, d.width - 10, d.height - 10, 10, 10);

			g.drawString(mensag, 20, 30);
		}

		public Insets getInsets()
		{
			return new Insets(10,10,10,10);
		}

		FontMetrics pickFont(Graphics g, String longString, int xSpace)
		{
			boolean fontFits = false;
			Font currentFont = biggestFont;
			FontMetrics currentMetrics = getFontMetrics(currentFont);
			int size = currentFont.getSize();
			String name = currentFont.getName();
			int style = currentFont.getStyle();

			while (!fontFits)
			{
				if ( (currentMetrics.getHeight() <= maxCharHeight) && (currentMetrics.stringWidth(longString) <= xSpace))
				{
                	fontFits = true;
            	}
            	else
            	{
                	if (size <= minFontSize)
                	{
                    	fontFits = true;
                	}
                	else
                	{
                    	currentFont = new Font(name, style, --size);
                    	currentMetrics = getFontMetrics(currentFont);
                	}
            	}
        	}

	        //Must set font in both component and Graphics object.
	        g.setFont(currentFont);
	        setFont(currentFont);
	        return currentMetrics;
		}
	}
}
