/****************************************
Classe responsvel para o registro do Log
****************************************/

import java.io.*;

public class ArqTexto
{
	private String fileName;
	private DataOutputStream output;
	private DataInputStream input;

	/*********
	Construtor
	**********/
	public ArqTexto(String arq) throws Exception
	{
		fileName = arq.trim().toUpperCase();

		if ( fileName.length() == 0)
		{
			throw new Exception("Nome do arquivo invlido!");
		}
	}

	/***************
	Ler arquivo
	****************/
	public String leArquivo() throws IOException
	{
		StringBuffer buf = new StringBuffer();
		byte caract;

		try
		{
			while(true)
			{
				caract = input.readByte();
				buf.append( caract );
			}
		}
		catch (EOFException e)
		{
			return buf.toString();
		}

		catch ( IOException ioe)
		{
			throw ioe;
		}

		catch ( Exception e)
		{
			throw new IOException(e.toString());
		}
	}

	/***************
	Inserir mensagem
	****************/
	public void gravaMsg(String msg) throws IOException
	{
		// Consiste o tamanho da mensagem
		if ( msg.length() == 0)
		{
			throw new IOException("Mensagem invlida!");
		}

		try
		{
			openOutputFile();
			addText(msg);
		}
		catch( IOException e)
		{
			throw e;
		}
	}

	/**************************
	Abre o arquivo para gravar
	***************************/
	private void openOutputFile() throws IOException
	{
		try
		{
			output = new DataOutputStream( new FileOutputStream( fileName, true ) );
		}
		catch ( IOException e )
		{
			throw e;
		}
	}

	/***************************
	Abre o arquivo para leitura
	***************************/
	private void openInputFile() throws IOException
	{
		try
		{
			input = new DataInputStream( new FileInputStream( fileName ) );
		}
		catch ( IOException e )
		{
			throw e;
		}
	}

	/************************
	Adiciona dados no arquivo
	*************************/
	private void addText(String xMsg) throws IOException
	{
		try
		{
			output.writeBytes(xMsg);
			output.flush();
		}
		catch ( IOException e )
		{
			throw e;
		}
	}

	/**************
	Fecha o arquivo
	***************/
	private void closeOutputFile() throws IOException
	{
		try
		{
			output.close();
		}
		catch ( IOException e )
		{
			throw e;
		}
	}

	/**************
	Fecha o arquivo
	***************/
	private void closeInputFile() throws IOException
	{
		try
		{
			input.close();
		}
		catch ( IOException e )
		{
			throw e;
		}
	}
}
