import java.awt.*;
import java.awt.event.*;

public class ComboLojaEst extends Panel implements ItemListener, KeyListener
{
	private Choice choLoja, choEstado;
	private Checkbox chkLoja, chkLogin, chkEstado;
	private TextField txtLogin;
	public static final Parametro param = new Parametro();
	private Informacao informacao;
	private List listaLoja, listaEstado;
	private String codigo[], codestado[];

	/*********
	Construtor
	**********/
	ComboLojaEst(	Informacao informacao,
					List listaLoja,
					List listaEstado,
					String[] codigo,
					String[] codestado)
	{
		super();

		this.informacao = informacao;
		this.listaLoja = listaLoja;
		this.listaEstado = listaEstado;
		this.codigo = codigo;
		this.codestado = codestado;

		Label lbl = new Label("Filtre o seu relatrio");
		lbl.setFont(param.get_Fonte());
		lbl.setBackground(param.get_BackColor());
		lbl.setForeground(param.get_ForeColor());

		choLoja = new Choice();
		choLoja.setEnabled(true);
		choLoja.setFont(param.get_Fonte());
		choLoja.setBackground(Color.white);
		choLoja.setForeground(Color.black);
		for ( int i = 0; i < listaLoja.getItemCount(); i++ )
			choLoja.add(listaLoja.getItem(i));

		choEstado = new Choice();
		choEstado.setEnabled(false);
		choEstado.setFont(param.get_Fonte());
		choEstado.setBackground(Color.white);
		choEstado.setForeground(Color.black);
		for ( int i = 0; i < listaEstado.getItemCount(); i++ )
			choEstado.add(listaEstado.getItem(i));

		chkLoja = new Checkbox("Loja");
		chkLoja.setBackground(param.get_BackColor());
		chkLoja.setState(true);
		chkLoja.addItemListener(this);

		chkEstado = new Checkbox("Estado");
		chkEstado.setBackground(param.get_BackColor());
		chkEstado.setState(false);
		chkEstado.addItemListener(this);
		if ( informacao.getTransaction() != 5 ) chkEstado.setEnabled(false);

		chkLogin = new Checkbox("Login");
		chkLogin.setBackground(param.get_BackColor());
		chkLogin.setState(false);
		chkLogin.addItemListener(this);

		txtLogin = new TextField(20);
		txtLogin.setEditable(false);
		txtLogin.addKeyListener(this);
		txtLogin.setBackground(param.get_ForeColor());
		txtLogin.setForeground(param.get_WriteColor());

		Panel pnlEsq = new Panel();
		pnlEsq.setLayout(new GridLayout(3,1,1,1));
		pnlEsq.add(chkLoja);
		pnlEsq.add(chkLogin);
		pnlEsq.add(chkEstado);

		Panel pnlDir = new Panel();
		pnlDir.setLayout(new GridLayout(3,1,1,1));
		pnlDir.add(choLoja);
		pnlDir.add(txtLogin);
		pnlDir.add(choEstado);

		Panel pnlPrinc = new Panel();
		pnlPrinc.setLayout(new BorderLayout());
		pnlPrinc.add(lbl, BorderLayout.NORTH);
		pnlPrinc.add(pnlEsq,BorderLayout.WEST);
		pnlPrinc.add(pnlDir,BorderLayout.EAST);

		setLayout(new FlowLayout());
		add(pnlPrinc);
	}

	public void chkLojaFocus()
	{
		chkLoja.requestFocus();
	}

	/*****************************************************************************
	Verifica quem originou o evento e define se o boto deve ou no ser habilitado
	******************************************************************************/
	public void itemStateChanged(ItemEvent e)
	{
		if ( e.getSource() == chkLoja )
		{
			if ( chkLoja.getState() )
			{
				choLoja.setEnabled(true);
				informacao.checaInfo();
			}
			else
			{
				choLoja.setEnabled(false);
				informacao.checaInfo();
			}
		}
		else if ( e.getSource() == chkLogin )
		{
			if ( chkLogin.getState() )
			{
				txtLogin.setEditable(true);
				informacao.checaInfo();
			}
			else
			{
				txtLogin.setEditable(false);
				informacao.checaInfo();
			}
		}
		else
		{
			if ( chkEstado.getState() )
			{
				choEstado.setEnabled(true);
				informacao.checaInfo();
			}
			else
			{
				choEstado.setEnabled(false);
				informacao.checaInfo();
			}
		}
	}

	public void keyTyped(KeyEvent e){}
	public void keyPressed(KeyEvent e) {}
	public void keyReleased(KeyEvent e)
	{
		informacao.checaInfo();
	}

	/**************
	Retorna o Login
	***************/
	public String getLogin()
	{
		return txtLogin.getText();
	}

	/*************************
	Retorna o tamanho do Login
	**************************/
	public int getSizeLogin()
	{
		return txtLogin.getText().length();
	}

	/*********************************************
	Verifica se o login possui um espao em branco
	**********************************************/
	public boolean getBlankLogin()
	{
		if ( txtLogin.getText().indexOf(" ") != -1 )
			return true;
		return false;
	}

	/***********************
	Retorna o cdigo da loja
	************************/
	public String getCodLoja()
	{
		return codigo[ choLoja.getSelectedIndex() ];
	}

	/***********************
	Retorna o status da loja
	************************/
	public boolean getStateLoja()
	{
		return chkLoja.getState();
	}

	/************************
	Retorna o status do login
	*************************/
	public boolean getStateLogin()
	{
		return chkLogin.getState();
	}

	/*************************
	Retorna o status do estado
	**************************/
	public boolean getStateEstado()
	{
		return chkEstado.getState();
	}

	/*************************
	Retorna o codigo do estado
	**************************/
	public String getCodEstado()
	{
		return codestado[ choEstado.getSelectedIndex() ];

	}

	public void update (Graphics g)
	{
		paint(g);
	}

	public void paint(Graphics g)
	{
		Dimension d = getSize();

		g.setColor(param.get_BackColor());
		g.fill3DRect(0, 0, d.width - 1, d.height - 1, true);

		g.setColor(Color.yellow);
		g.drawRoundRect(5, 5, d.width - 10, d.height - 10, 10, 10);
	}

	public Insets getInsets()
	{
		return new Insets(10,10,10,10);
	}
}
