import java.awt.*;
import java.awt.event.*;
import java.net.MalformedURLException;
import java.util.*;
import java.text.*;
import java.text.SimpleDateFormat;

public class DataInfo extends Panel implements KeyListener
{
	private TextField txtIni;
	private TextField txtFim;
	private Informacao informacao;
	public static final Parametro param = new Parametro();
	private String focus;

	/*********
	Construtor
	**********/
	DataInfo(Informacao informacao)
	{
		super();

		this.informacao = informacao;
		focus=".";

		Label lblIni = new Label("Data Inicial");
		lblIni.setBackground(param.get_BackColor());
		lblIni.setForeground(param.get_ForeColor());

		Label lblFim = new Label("Data Final");
		lblFim.setBackground(param.get_BackColor());
		lblFim.setForeground(param.get_ForeColor());

		txtIni = new TextField(20);
		txtIni.setBackground(param.get_ForeColor());
		txtIni.setForeground(param.get_WriteColor());
		txtIni.setName("txtIni");
		txtIni.addKeyListener(this);

		txtFim = new TextField(20);
		txtFim.setBackground(param.get_ForeColor());
		txtFim.setForeground(param.get_WriteColor());
		txtFim.setName("txtFim");
		txtFim.addKeyListener(this);

		if ( informacao.getTransaction() == 8 )
		{
			txtIni.setEditable(false);
			txtFim.setEditable(false);
			lblIni.setEnabled(false);
			lblFim.setEnabled(false);
		}

		Panel p1 = new Panel();
		p1.setLayout(new GridLayout(2,1,1,1));
		p1.add(lblIni);
		p1.add(lblFim);

		Panel p2 = new Panel();
		p2.setLayout(new GridLayout(2,1,1,1));
		p2.add(txtIni);
		p2.add(txtFim);

		Label lblFormat = new Label("Formato da Data : DD-MM-AAAA",Label.CENTER);
		lblFormat.setFont(param.get_Fonte());

		setLayout(new BorderLayout(5,5));
		add(p1,"West");
		add(p2,"Center");
		add(lblFormat,"South");

		setBackground(param.get_BackColor());
		setForeground(param.get_ForeColor());
	}

	public void txtIniFocus()
	{
		txtIni.requestFocus();
	}

	public void txtFimFocus()
	{
		txtFim.requestFocus();
	}

    public void keyTyped(KeyEvent e){}
	public void keyPressed(KeyEvent e){}
	public void keyReleased(KeyEvent e)
	{
        // Consiste o caracter TAB ou ENTER
		if(focus.equals("txtIni"))
		{
			try
			{
				getDataIni();
				txtFimFocus();
			}
			catch(Exception e1) {};
		}

		if(focus.equals("txtFim"))
		{
			try
			{
				getDataFim();
				informacao.chkLojaFocus();
				focus = "";
			}
			catch(Exception e2) {};
		}

		focus = e.getComponent().getName();
		informacao.checaInfo();
	}

	/*********************
	Retorna a Data inicial
	**********************/
	public String getDataIni() throws Exception
	{
		try
		{
			String dt = getDataFormatada( getCalendar(txtIni.getText()));
			return dt;
		}
		catch (Exception e)
		{
			throw new Exception("Data inicial:"+e.toString());
		}
	}

	/*******************
	Retorna a Data final
	********************/
	public String getDataFim() throws Exception
	{
		try
		{
			String dt = getDataFormatada( getCalendar(txtFim.getText()));
			return dt;
		}
		catch (Exception e)
		{
			throw new Exception("Data final:"+e.toString());
		}
	}

	public void setDataFim(String dt)
	{
		txtFim.setText(dt);
	}

	/****************************
	Inverte data para yyyy-mm-dd
	*****************************/
	private String inverteData(String dt)
	{
		try
		{
			return dt.substring(6,10) +
				   dt.substring(5,6) +
				   dt.substring(3,5) +
				   dt.substring(2,3) +
				   dt.substring(0,2);
		}
		catch (Exception e)
		{
			return " ";
		}
	}

	/*******************************
	Retorna a Data inicial invertida
	********************************/
	public String getDataIniInv() throws Exception
	{
		try
		{
			return (inverteData(getDataIni())+param.getSeparador()+"00:00:00");
		}
		catch (Exception e)
		{
			throw new Exception("Data inicial:"+e.getMessage());
		}
	}

	/*****************************
	Retorna a Data final invertida
	******************************/
	public String getDataFimInv() throws Exception
	{
		try
		{
			return (inverteData(getDataFim())+param.getSeparador()+"23:59:59");
		}
		catch (Exception e)
		{
			throw new Exception("Data final:"+e.getMessage());
		}
	}

	/**********************************
	Retorna o tamanho da String DataIni
	***********************************/
	public int getSizeDataIni()
	{
		try
		{
			return getDataIni().length();
		}
		catch (Exception e)
		{
			return 0;
		}
	}

	/**********************************
	Retorna o tamanho da String DataFim
	***********************************/
	public int getSizeDataFim()
	{
		try
		{
			return getDataFim().length();
		}
		catch (Exception e)
		{
			return 0;
		}
	}

	/*******************************************
	Retorna o status dos textfields Inicio e Fim
	********************************************/
	public boolean getStatus()
	{
		return (txtIni.isEditable() && txtFim.isEditable());
	}

	public void update (Graphics g)
	{
		paint(g);
	}

	public void paint (Graphics g)
	{
		Dimension d = getSize();

		g.setColor(param.get_BackColor());
		g.fill3DRect(0, 0, d.width - 1, d.height - 1, true);

		g.setColor(Color.yellow);
		g.drawRoundRect(5, 5, d.width - 10, d.height - 10, 10, 10);
	}

	public Insets getInsets()
	{
		return new Insets(10,10,10,10);
	}

	/*********************
	Verifica data valida
	*********************/
	public Calendar getCalendar( String strData ) throws Exception
	{
		Locale loc = new Locale("en","US");
		SimpleDateFormat df = new SimpleDateFormat("dd-MM-yyyy",loc);
		int max_dias[]={31,28,31,30,31,30,31,31,30,31,30,31};

		try
		{
			Date x = df.parse( strData );
			Calendar c = Calendar.getInstance(Locale.US);
			c.setLenient(false);
			c.set(Integer.parseInt(strData.substring(6,10)),
			      Integer.parseInt(strData.substring(3,5)) - 1,
			      Integer.parseInt(strData.substring(0,2)));
			return c;
		}
		catch ( ParseException pe)
		{
			throw new Exception("Formato invlido");
		}
		catch ( IllegalArgumentException iaex )
		{
			throw new Exception("Data invlida");
		}
		catch ( IndexOutOfBoundsException iobex )
		{
			throw new Exception("Data invlida");
		}
	}

	/**************************************************************
	Valida datas ( Qtd. de dias no ms, inicial maior que final
	***************************************************************/
	public void periodoValido() throws Exception
	{
		Calendar dataIni, dataFim, dataMax, dataPref;

		// Consiste a data inicial
		try
		{
			dataIni = getCalendar( getDataIni() );
			dataPref = getCalendar( getDataIni() );
			dataPref.add(Calendar.MONTH, +1);
		}
		catch (Exception ex1)
		{
			throw new Exception("Erro na data inicial: "+ex1.getMessage());
		}

		// Consiste a data maxima
		try
		{
			dataMax = getCalendar( getDataFormatada(dataPref) );
			dataMax.add(Calendar.DAY_OF_MONTH, +1);
		}
		catch ( Exception ex2 )
		{
			throw new Exception("Erro ao obter data mxima: "+ex2.getMessage());
		}

		// Consiste a data final
		try
		{
			dataFim = getCalendar( getDataFim() );
		}
		catch ( Exception ex3 )
		{
			throw new Exception("Erro na data final: "+ex3.getMessage());
		}

		// Validade do perodo
		try
		{
		  	if ( dataIni.after(dataFim) )
		  	{
				throw new Exception("Data inicial maior que data final !");
			}

			if ( dataFim.after(dataMax) )
			{
				setDataFim(getDataFormatada(dataPref));	// Corrige data final
				throw new Exception("Data final nao pode ser superior a "+getDataFormatada(dataPref));
			}
		}
		catch (Exception ex4)
		{
		 	throw ex4;
		}
	}

	/***********************
	 Retorna data formatada
	***********************/
	public String getDataFormatada( Calendar cal ) throws Exception
	{
		String result;
		Locale loc = new Locale("en", "US");
		SimpleDateFormat df = new SimpleDateFormat("dd-MM-yyyy", loc);

		try
		{
			result = df.format( cal.getTime() );
			return result;
		}
		catch (Exception e)
		{
			throw e;
		}
	}
}